//
//  YHActivityDetailViewController.swift
//  galaxy
//
//  Created by davidhuangA on 2024/6/20.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHActivityDetailViewController: YHBaseViewController {
    var activityId : String = ""
    
    lazy var viewModel: YHActivityViewModel = {
        let vm = YHActivityViewModel()
        return vm
    }()
    
    lazy var tableView: UITableView = {
        let tableView = UITableView(frame:.zero, style:.plain)
        tableView.showsVerticalScrollIndicator = false
        tableView.separatorStyle = .none
        tableView.delegate = self
        tableView.dataSource = self
        tableView.backgroundColor = UIColor.white
        tableView.register(UITableViewCell.self, forCellReuseIdentifier: "UITableViewCell")
        tableView.register(YHActivityDetailCell.self, forCellReuseIdentifier: YHActivityDetailCell.cellReuseIdentifier)
        tableView.tableHeaderView =  nil
        tableView.tableFooterView = nil
        
        tableView.estimatedSectionHeaderHeight = 0
        tableView.estimatedSectionFooterHeight = 0
        
        return tableView
    }()
    
    lazy var topView : UIImageView = {
        let view = UIImageView()
        view.contentMode = .scaleAspectFill
        view.image = UIImage(named: "activity_detail_top_bkg")
        return view
    }()
    
    lazy var bottomView : YHActivityDetailBottomView = {
        let view = YHActivityDetailBottomView()
        return view
    }()
    
    
    // MARK: - 生命周期方法
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        loadData()
    }
}

extension YHActivityDetailViewController {
    func gotoTheRightVcForStatus() {
        guard let model = self.viewModel.activityDetailModel  else {
            return
        }
        
        if let status = YHActivityStatus(rawValue: model.status.int ?? 0) {
            switch status {
            case .notApply:
//                printLog("立即报名")
                showApplyUI()
            case .applied:
                printLog("已报名")
                let vc = YHActivityTravelViewController()
                vc.travelId = viewModel.activityDetailModel?.checkId ?? ""
                navigationController?.pushViewController(vc)
            case .canceled:
//                printLog("已取消报名")
                showApplyUI()
            case .end:
                printLog("活动已结束")
                YHHUD.flash(message: "活动已结束")
            default:
                printLog("")
            }
        }
        
    }
    
    func showApplyUI() {
        YHApplyActivityAlert.showApplyActivityAlertView(name: self.viewModel.activityDetailModel?.businessCardName ?? "") { (tag,name,number,phone) in
            if tag {
                printLog(tag)
                printLog(name)
                printLog(number)
                printLog(phone)
                if tag {
                    let param = ["id" : self.activityId,
                                 "name":name,
                                 "mobile":phone,
                                 "number":number]
                    self.applyActivity(param: param)
                }
            }
        }
    }
    
    func setupUI() {
        gk_navigationBar.isHidden = false
        gk_navigationBar.backgroundColor = .clear
        
        //1.
        view.addSubview(tableView)
        view.addSubview(bottomView)
        view.addSubview(topView)
        
        //2.
        tableView.contentInsetAdjustmentBehavior = .never
        tableView.snp.makeConstraints { make in
            make.left.right.top.equalToSuperview()
            make.bottom.equalTo(bottomView.snp.top)
        }
        
        //3.
        bottomView.snp.makeConstraints { make in
            make.left.right.bottom.equalToSuperview()
            make.height.equalTo(YHActivityDetailBottomView.viewH)
        }
        
        bottomView.block = { [weak self] tag in
            //判断是否登录成功
            if YHLoginManager.shared.isLogin() {
                self?.gotoTheRightVcForStatus()
            } else {
                YHOneKeyLoginManager.shared.oneKeyLogin()
                YHLoginManager.shared.loginSuccessActionBlock = {[weak self] in
                    guard self != nil else { return }
                    self?.gotoTheRightVcForStatus()
                    YHLoginManager.shared.loginSuccessActionBlock = nil
                }
            }
        }
        
        //4.
        topView.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.height.equalTo(114)
        }
    }
    func loadData() {
        if !activityId.isEmpty {
            viewModel.getActivityDetailData(activityID: activityId) { success, error in
                if success {
                    //tableView
                    self.tableView.reloadData()
                    
                    //bottomView
                    self.bottomView.dataModel = self.viewModel.activityDetailModel
                } else {
                    let msg = error?.errorMsg ?? "获取数据出错"
                    YHHUD.flash(message: msg)
                    self.navigationController?.popViewController()
                }
            }
        } else {
            YHHUD.flash(message: "参数错误")
            navigationController?.popViewController()
        }
    }
    
    
    func applyActivity(param : [String : Any]) {
        
        viewModel.applyActivity(param: param) { success, error in
            if success {
                YHHUD.flash(message: "报名成功")
                self.loadData()
                DispatchQueue.main.async {
                    let vc = YHApplyActivityResultViewController()
                    vc.isSuccessFlag = true
                    vc.activityTravelId = self.viewModel.travelModel?.id ?? ""
                    vc.activityName = self.viewModel.activityDetailModel?.name ?? ""
                    self.navigationController?.pushViewController(vc)
                }
            } else {
                let msg = error?.errorMsg ?? "报名失败,请重试"
                YHHUD.flash(message: msg)
            }
        }
    }
}

extension YHActivityDetailViewController: UITableViewDelegate, UITableViewDataSource {
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: YHActivityDetailCell.cellReuseIdentifier, for: indexPath) as! YHActivityDetailCell
        cell.dataModel = viewModel.activityDetailModel
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return UITableView.automaticDimension
    }
}
