//
//  YHPeopleViewController.swift
//  galaxy
//
//  Created by EDY on 2024/6/17.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import JXSegmentedView
import Lottie

class YHPeopleViewController: YHBaseViewController {
    let viewModel = YHMatchUserViewModel()
    var informationAuthorizeViewModel: YHInformationAuthorizeViewModel = YHInformationAuthorizeViewModel()

    lazy var topLabel:UILabel = {
        let label = UILabel()
        label.textAlignment = .center
        label.textColor = UIColor.white
        label.font = UIFont.PFSC_R(ofSize:16)
        label.text = "为您匹配适合您的优质人脉"
        return label
    }()
    
    lazy var bottomBtn:UIButton = {
        let btn = UIButton()
        btn.backgroundColor = .brandMainColor
        btn.setTitle("AI人脉雷达匹配", for: .normal)
        btn.setTitleColor(.white, for: .normal)
        btn.titleLabel?.font = .PFSC_M(ofSize: 15)
        btn.layer.cornerRadius = 3.0
        btn.addTarget(self, action: #selector(didMatchBtnClicked), for: .touchUpInside)
        return btn
    }()
    
    lazy var headLottieView: LottieAnimationView = {
        let view = LottieAnimationView(name: "people_head")
        view.loopMode = .loop
        return view
    }()
    
    lazy var launchLottieView: LottieAnimationView = {
        let view = LottieAnimationView(name: "people_launch")
        return view
    }()
    
    lazy var rotateLottieView: LottieAnimationView = {
        let view = LottieAnimationView(name: "people_rotate")
        view.isHidden = true
        return view
    }()
    
    lazy var bottomLabel:UILabel = {
        let label = UILabel()
        label.textAlignment = .center
        label.textColor = UIColor.mainTextColor70
        label.font = UIFont.PFSC_R(ofSize:13)
        label.text = "授权基础信息，获取更多人脉"
        return label
    }()
    
    lazy var firstImageView: UIImageView = {
        let imageView = UIImageView()
        imageView.image = UIImage(named: "people_first_bg_image")
        imageView.isHidden = true
        return imageView
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        gk_navigationBar.isHidden = true
        self.view.backgroundColor = .clear
        createUI()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        informationAuthorizeViewModel.requestUserInfo {[weak self] success, error in
            guard let self = self else { return }
            if informationAuthorizeViewModel.model.is_fillin != 1 {
                self.firstImageView.isHidden = false
                self.bottomLabel.isHidden = false
                self.headLottieView.isHidden = true
                self.launchLottieView.isHidden = true
                self.rotateLottieView.isHidden = true
            } else {
                self.firstImageView.isHidden = true
                self.bottomLabel.isHidden = true
                self.headLottieView.isHidden = false
                self.launchLottieView.isHidden = false
                self.rotateLottieView.isHidden = true
            }
        }
    }
    
    func createUI() {
        
        let wingLeftImgV = UIImageView(image: UIImage(named: "people_match_wing_left"))
        self.view.addSubview(wingLeftImgV)
        
        let wingRightImgV = UIImageView(image: UIImage(named: "people_match_wing_right"))
        self.view.addSubview(wingRightImgV)
        
        self.view.addSubview(topLabel)
        self.view.addSubview(firstImageView)
        self.view.addSubview(self.bottomBtn)
        self.view.addSubview(self.bottomLabel)
        
        self.view.addSubview(launchLottieView)
        self.view.addSubview(rotateLottieView)
        self.view.addSubview(headLottieView)
        self.headLottieView.play()

        launchLottieView.snp.makeConstraints { make in
            make.width.height.equalTo(KScreenWidth)
            make.centerX.equalToSuperview()
            make.top.equalTo(204-48-k_Height_statusBar())
        }
        headLottieView.snp.makeConstraints { make in
            make.width.height.equalTo(KScreenWidth)
            make.center.equalTo(launchLottieView)
        }
        rotateLottieView.snp.makeConstraints { make in
            make.width.height.equalTo(KScreenWidth)
            make.center.equalTo(launchLottieView)
        }
        
        firstImageView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.height.equalTo(547)
            make.bottom.equalTo(-k_Height_safeAreaInsetsBottom())
        }
        self.topLabel.snp.makeConstraints { make in
            make.centerX.equalToSuperview()
            make.top.equalTo(50)
            make.height.equalTo(22)
        }
        
        self.bottomBtn.snp.makeConstraints { make in
            make.left.equalTo(24)
            make.right.equalTo(-24)
            make.height.equalTo(48.0)
            make.bottom.equalTo(-k_Height_safeAreaInsetsBottom()-48-60)
        }
        
        self.bottomLabel.snp.makeConstraints { make in
            make.left.equalTo(24)
            make.right.equalTo(-24)
            make.height.equalTo(18.0)
            make.top.equalTo(self.bottomBtn.snp.bottom).offset(12)
        }
        
        wingLeftImgV.snp.makeConstraints { make in
            make.width.height.equalTo(19)
            make.right.equalTo(self.topLabel.snp.left)
            make.centerY.equalTo(self.topLabel)
        }
        wingRightImgV.snp.makeConstraints { make in
            make.width.height.equalTo(19)
            make.left.equalTo(self.topLabel.snp.right)
            make.centerY.equalTo(self.topLabel)
        }
    }
    
    @objc func didMatchBtnClicked() {
        
        if !YHLoginManager.shared.isLogin() {
            YHOneKeyLoginManager.shared.oneKeyLogin()
            return
        }
        if informationAuthorizeViewModel.model.is_fillin == 1 {
            startMatchUsers()
        } else {
            let vc = YHInformationAuthorizationStepOneViewController()
            self.navigationController?.pushViewController(vc)
        }
    }
    
    func resetAnimation() {
        self.launchLottieView.stop()
        self.rotateLottieView.stop()
        self.headLottieView.isHidden = false
        self.launchLottieView.isHidden = false
        self.rotateLottieView.isHidden = true
    }
}

extension YHPeopleViewController: JXSegmentedListContainerViewListDelegate {
    func listView() -> UIView {
        return view
    }
}

extension YHPeopleViewController: YHMatchProtocol {
    func startMatchUsers() {
        self.headLottieView.isHidden = true
        self.launchLottieView.isHidden = false
        self.launchLottieView.loopMode = .playOnce
        self.launchLottieView.play {
            [weak self] completed in
            guard let self = self else { return }
            self.launchLottieView.isHidden = true
            self.rotateLottieView.isHidden = false
            self.rotateLottieView.loopMode = .loop
            self.rotateLottieView.play()
            self.requestMatchUserList()
        }
    }
}

extension YHPeopleViewController {
    func requestMatchUserList() {
        self.viewModel.getMatchUserlist { 
            success, error in
            
            if success, self.viewModel.matchUserArr.count > 0 {
                let vc = YHMatchPeopleViewController()
                vc.delegate = self
                vc.matchUsersArr = self.viewModel.matchUserArr
                self.navigationController?.pushViewController(vc)
                
            } else {
                var msg = "匹配失败"
                if let errorMsg = error?.errorMsg, !errorMsg.isEmpty {
                    msg = errorMsg
                }
                YHHUD.flash(message: msg)
            }
            self.resetAnimation()
        }
    }
    
}

